pub struct AllSubstitutionFunctions(IndexMap<Key, ComputedValue, FxBuildHasher>);Expand description
An IndexMap containing both custom properties and attributes.
Tuple Fields
0: IndexMap<Key, ComputedValue, FxBuildHasher>Implementations
Sourceimpl AllSubstitutionFunctions
impl AllSubstitutionFunctions
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether the map has zero properties and attributes in it.
Sourcepub fn get(
&self,
name: &Name,
kind: SubstitutionFunctionKind,
) -> Option<&ComputedRegisteredValue>
pub fn get( &self, name: &Name, kind: SubstitutionFunctionKind, ) -> Option<&ComputedRegisteredValue>
Returns a custom property or attribute value by name.
Sourcepub fn insert(
&mut self,
name: &Name,
kind: SubstitutionFunctionKind,
value: ComputedRegisteredValue,
)
pub fn insert( &mut self, name: &Name, kind: SubstitutionFunctionKind, value: ComputedRegisteredValue, )
Inserts an element into the map.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = (&Name, SubstitutionFunctionKind, &ComputedRegisteredValue)>
pub fn iter( &self, ) -> impl Iterator<Item = (&Name, SubstitutionFunctionKind, &ComputedRegisteredValue)>
Returns iterator to go through all substitution functions in insertion order.